@@ -1,26 +1,35 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# MantisBT - a php based bugtracking system
 
-	# --------------------------------------------------------
-	# $Id: make_captcha_img.php,v 1.6 2004/10/25 19:45:04 marcelloscata Exp $
-	# --------------------------------------------------------
+# MantisBT is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# MantisBT is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
-	# ======================================================================
-	# Author: Marcello Scata' <marcelloscata at users.sourceforge.net> ITALY
-	# ======================================================================
-
-#	ob_start();
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @author Marcello Scata' <marcelloscata at users.sourceforge.net> ITALY
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
-#	ob_flush();
 
 	$f_public_key = gpc_get_int( 'public_key' );
 
-	$t_key = strtolower( substr( md5( config_get( 'password_confirm_hash_magic_string' ) . $f_public_key ), 1, 5) );
-	$t_system_font_folder = config_get( 'system_font_folder' );
+	$t_key = utf8_strtolower( utf8_substr( md5( config_get( 'password_confirm_hash_magic_string' ) . $f_public_key ), 1, 5) );
+	$t_system_font_folder = get_font_path();
 	$t_font_per_captcha = config_get( 'font_per_captcha' );
 
 	$t_captcha_init = array(
@@ -28,10 +37,10 @@
 		'TTF_RANGE'      => array( $t_font_per_captcha )
 	);
 
-	$captcha =& new masc_captcha( $t_captcha_init );
+	$captcha = new masc_captcha( $t_captcha_init );
 	$captcha->make_captcha( $t_key );
 
-# 
+#
 # The class below was derived from
 # http://www.phpclasses.org/browse/package/1163.html
 #
@@ -44,19 +53,19 @@
 #
 # *** 3.1 License
 # GNU General Public License (Version 2, June 1991)
-# 
+#
 # This program is free software; you can redistribute
 # it and/or modify it under the terms of the GNU
 # General Public License as published by the Free
 # Software Foundation; either version 2 of the License,
 # or (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will
 # be useful, but WITHOUT ANY WARRANTY; without even the
 # implied warranty of MERCHANTABILITY or FITNESS FOR A
 # PARTICULAR PURPOSE. See the GNU General Public License
 # for more details.
-# 
+#
 
 	class masc_captcha
 	{
@@ -87,12 +96,12 @@
 				// Test for GD-Library(-Version)
 				$this->gd_version = get_gd_version();
 				if($this->gd_version == 0) die("There is no GD-Library-Support enabled. The Captcha-Class cannot be used!");
-				if($this->debug) echo "\n<br>-Captcha-Debug: The available GD-Library has major version ".$this->gd_version;
+				if($this->debug) echo "\n<br />-Captcha-Debug: The available GD-Library has major version ".$this->gd_version;
 
 				// extracts config array
 				if(is_array($config))
 				{
-					if($this->debug) echo "\n<br>-Captcha-Debug: Extracts Config-Array in unsecure-mode!";
+					if($this->debug) echo "\n<br />-Captcha-Debug: Extracts Config-Array in unsecure-mode!";
 					foreach($config as $k=>$v) $this->$k = $v;
 				}
 
@@ -102,45 +111,45 @@
 					$temp = $this->minsize;
 					$this->minsize = $this->maxsize;
 					$this->maxsize = $temp;
-					if($this->debug) echo "<br>-Captcha-Debug: Arrghh! What do you think I mean with min and max? Switch minsize with maxsize.";
+					if($this->debug) echo "<br />-Captcha-Debug: Arrghh! What do you think I mean with min and max? Switch minsize with maxsize.";
 				}
 
 				// check TrueTypeFonts
 				if(is_array($this->TTF_RANGE))
 				{
-					if($this->debug) echo "\n<br>-Captcha-Debug: Check given TrueType-Array! (".count($this->TTF_RANGE).")";
+					if($this->debug) echo "\n<br />-Captcha-Debug: Check given TrueType-Array! (".count($this->TTF_RANGE).")";
 					$temp = array();
 					foreach($this->TTF_RANGE as $k=>$v)
 					{
 						if(is_readable($this->TTF_folder.$v)) $temp[] = $v;
 					}
 					$this->TTF_RANGE = $temp;
-					if($this->debug) echo "\n<br>-Captcha-Debug: Valid TrueType-files: (".count($this->TTF_RANGE).")";
+					if($this->debug) echo "\n<br />-Captcha-Debug: Valid TrueType-files: (".count($this->TTF_RANGE).")";
 					//if(count($this->TTF_RANGE) < 1) die('No Truetypefont available for the CaptchaClass.');
 				}
 				else
 				{
-					if($this->debug) echo "\n<br>-Captcha-Debug: Check given TrueType-File! (".$this->TTF_RANGE.")";
+					if($this->debug) echo "\n<br />-Captcha-Debug: Check given TrueType-File! (".$this->TTF_RANGE.")";
 					if(!is_readable($this->TTF_folder.$this->TTF_RANGE)) die('No Truetypefont available for the CaptchaClass.');
 				}
 
 				// select first TrueTypeFont
 				$this->change_TTF();
-				if($this->debug) echo "\n<br>-Captcha-Debug: Set current TrueType-File: (".$this->TTF_file.")";
+				if($this->debug) echo "\n<br />-Captcha-Debug: Set current TrueType-File: (".$this->TTF_file.")";
 
 				// get number of noise-chars for background if is enabled
 				$this->nb_noise = $this->noise ? ($this->chars * $this->noisefactor) : 0;
-				if($this->debug) echo "\n<br>-Captcha-Debug: Set number of noise characters to: (".$this->nb_noise.")";
+				if($this->debug) echo "\n<br />-Captcha-Debug: Set number of noise characters to: (".$this->nb_noise.")";
 
 				// set dimension of image
 				$this->lx = ($this->chars + 1) * (int)(($this->maxsize + $this->minsize) / 1.5);
 				$this->ly = (int)(2.4 * $this->maxsize);
-				if($this->debug) echo "\n<br>-Captcha-Debug: Set image dimension to: (".$this->lx." x ".$this->ly.")";
+				if($this->debug) echo "\n<br />-Captcha-Debug: Set image dimension to: (".$this->lx." x ".$this->ly.")";
 			}
 
 			function make_captcha( $private_key )
 			{
-				if($this->debug) echo "\n<br>-Captcha-Debug: Generate private key: ($private_key)";
+				if($this->debug) echo "\n<br />-Captcha-Debug: Generate private key: ($private_key)";
 
 				// create Image and set the apropriate function depending on GD-Version & websafecolor-value
 				if($this->gd_version >= 2 && !$this->websafecolors)
@@ -154,25 +163,23 @@
 					$func2 = 'imagecolorclosest';
 				}
 				$image = $func1($this->lx,$this->ly);
-				if($this->debug) echo "\n<br>-Captcha-Debug: Generate ImageStream with: ($func1())";
-				if($this->debug) echo "\n<br>-Captcha-Debug: For colordefinitions we use: ($func2())";
-
+				if($this->debug) echo "\n<br />-Captcha-Debug: Generate ImageStream with: ($func1())";
+				if($this->debug) echo "\n<br />-Captcha-Debug: For colordefinitions we use: ($func2())";
 
 				// Set Backgroundcolor
 				$this->random_color(224, 255);
 				$back =  @imagecolorallocate($image, $this->r, $this->g, $this->b);
 				@ImageFilledRectangle($image,0,0,$this->lx,$this->ly,$back);
-				if($this->debug) echo "\n<br>-Captcha-Debug: We allocate one color for Background: (".$this->r."-".$this->g."-".$this->b.")";
+				if($this->debug) echo "\n<br />-Captcha-Debug: We allocate one color for Background: (".$this->r."-".$this->g."-".$this->b.")";
 
 				// allocates the 216 websafe color palette to the image
 				if($this->gd_version < 2 || $this->websafecolors) $this->makeWebsafeColors($image);
 
-
 				// fill with noise or grid
 				if($this->nb_noise > 0)
 				{
 					// random characters in background with random position, angle, color
-					if($this->debug) echo "\n<br>-Captcha-Debug: Fill background with noise: (".$this->nb_noise.")";
+					if($this->debug) echo "\n<br />-Captcha-Debug: Fill background with noise: (".$this->nb_noise.")";
 					for($i=0; $i < $this->nb_noise; $i++)
 					{
 						srand((double)microtime()*1000000);
@@ -197,14 +204,14 @@
 				else
 				{
 					// generate grid
-					if($this->debug) echo "\n<br>-Captcha-Debug: Fill background with x-gridlines: (".(int)($this->lx / (int)($this->minsize / 1.5)).")";
+					if($this->debug) echo "\n<br />-Captcha-Debug: Fill background with x-gridlines: (".(int)($this->lx / (int)($this->minsize / 1.5)).")";
 					for($i=0; $i < $this->lx; $i += (int)($this->minsize / 1.5))
 					{
 						$this->random_color(160, 224);
 						$color	= $func2($image, $this->r, $this->g, $this->b);
 						@imageline($image, $i, 0, $i, $this->ly, $color);
 					}
-					if($this->debug) echo "\n<br>-Captcha-Debug: Fill background with y-gridlines: (".(int)($this->ly / (int)(($this->minsize / 1.8))).")";
+					if($this->debug) echo "\n<br />-Captcha-Debug: Fill background with y-gridlines: (".(int)($this->ly / (int)(($this->minsize / 1.8))).")";
 					for($i=0 ; $i < $this->ly; $i += (int)($this->minsize / 1.8))
 					{
 						$this->random_color(160, 224);
@@ -214,10 +221,10 @@
 				}
 
 				// generate Text
-				if($this->debug) echo "\n<br>-Captcha-Debug: Fill forground with chars and shadows: (".$this->chars.")";
+				if($this->debug) echo "\n<br />-Captcha-Debug: Fill forground with chars and shadows: (".$this->chars.")";
 				for($i=0, $x = intval(rand($this->minsize,$this->maxsize)); $i < $this->chars; $i++)
 				{
-					$text	= strtoupper(substr($private_key, $i, 1));
+					$text	= utf8_strtoupper(substr($private_key, $i, 1));
 					srand((double)microtime()*1000000);
 					$angle	= intval(rand(($this->maxrotation * -1), $this->maxrotation));
 					srand((double)microtime()*1000000);
@@ -241,7 +248,7 @@
 				header('Content-type: image/jpeg');
 				@ImageJPEG($image, '', $this->jpegquality);
 				@ImageDestroy($image);
-				if($this->debug) echo "\n<br>-Captcha-Debug: Destroy Imagestream.";
+				if($this->debug) echo "\n<br />-Captcha-Debug: Destroy Imagestream.";
 			}
 
 			/** @private **/
@@ -258,7 +265,7 @@
 						}
 					}
 				}
-				if($this->debug) echo "\n<br>-Captcha-Debug: Allocate 216 websafe colors to image: (".imagecolorstotal($image).")";
+				if($this->debug) echo "\n<br />-Captcha-Debug: Allocate 216 websafe colors to image: (".imagecolorstotal($image).")";
 			}
 
 			function random_color($min,$max)
@@ -289,5 +296,3 @@
 			}
 
 	} // END CLASS masc_captcha
-
-?>
