@@ -1,30 +1,31 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: manage_config_email_set.php,v 1.10.2.1 2007-10-13 22:33:23 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
-	$t_core_path = config_get( 'core_path' );
-	require_once( $t_core_path.'email_api.php' );
+	require_once( 'email_api.php' );
 
 	form_security_validate('manage_config_email_set');
 
@@ -40,9 +41,7 @@
 	$f_thresholds		= gpc_get( 'flag_threshold', array() );
 	$f_actions_access	= gpc_get_int( 'notify_actions_access' );
 
-	html_page_top1( lang_get( 'manage_email_config' ) );
-	html_meta_redirect( $t_redirect_url );
-	html_page_top2();
+	html_page_top( lang_get( 'manage_email_config' ), $t_redirect_url );
 
 	$t_access = current_user_get_access_level();
 	$t_can_change_flags = $t_access >= config_get_access( 'notify_flags' );
@@ -53,11 +52,10 @@
 	if( config_get( 'enable_sponsorship' ) == ON ) {
 		$t_valid_actions[] = 'sponsor';
 	}
-	if( config_get( 'enable_relationship' ) == ON ) {
-		$t_valid_actions[] = 'relationship';
-	}
-	
-	$t_statuses = get_enum_to_array( config_get( 'status_enum_string' ) );
+
+	$t_valid_actions[] = 'relationship';
+
+	$t_statuses = MantisEnum::getAssocArrayIndexedByValues( config_get( 'status_enum_string' ) );
     ksort( $t_statuses );
     reset( $t_statuses );
 
@@ -75,11 +73,11 @@
 
 	# parse flags and thresholds
 	foreach( $f_flags as $t_flag_value ) {
-		list( $t_action, $t_flag ) = split( ':', $t_flag_value );
+		list( $t_action, $t_flag ) = explode( ':', $t_flag_value );
 		$t_flags[$t_action][$t_flag] = ON;
 	}
 	foreach( $f_thresholds as $t_threshold_value ) {
-		list( $t_action, $t_threshold ) = split( ':', $t_threshold_value );
+		list( $t_action, $t_threshold ) = explode( ':', $t_threshold_value );
 		if ( $t_threshold < $t_thresholds_min[$t_action] ) {
 			$t_thresholds_min[$t_action] = $t_threshold;
 		}
@@ -96,7 +94,7 @@
 		foreach ( $t_valid_flags as $t_flag ) {
 			$t_default_flags[$t_flag] = ON;
 			foreach ( $t_valid_actions as $t_action ) {
-				if ( ! isset( $t_flags[$t_action][$t_flag] ) ) {
+				if ( !isset( $t_flags[$t_action][$t_flag] ) ) {
 					unset( $t_default_flags[$t_flag] );
 				}
 			}
@@ -117,7 +115,7 @@
 
 		$t_existing_default_flags = config_get( 'default_notify_flags' );
 		$t_existing_default_access = config_get_access( 'default_notify_flags' );
-		if ( ( $t_existing_default_flags != $t_default_flags ) 
+		if ( ( $t_existing_default_flags != $t_default_flags )
 				|| ( $t_existing_default_access != $f_actions_access ) ) { # only set the flags if they are different
             config_set( 'default_notify_flags', $t_default_flags, NO_USER, $t_project, $f_actions_access );
         }
@@ -130,7 +128,7 @@
 	foreach ( $t_valid_actions as $t_action ) {
 		$t_action_printed = false;
 		foreach ( $t_valid_flags as $t_flag ) {
-			if ( ! isset( $t_default_flags[$t_flag] ) ) {
+			if ( !isset( $t_default_flags[$t_flag] ) ) {
 				$t_default_flags[$t_flag] = OFF;
 			}
 			if ( isset( $t_flags[$t_action][$t_flag] ) <> $t_default_flags[$t_flag] ) {
@@ -147,7 +145,7 @@
 	if ( isset( $t_notify_flags ) ) {
 		$t_existing_flags = config_get( 'notify_flags' );
 		$t_existing_access = config_get_access( 'notify_flags' );
-		if ( ( $t_existing_flags != $t_notify_flags ) 
+		if ( ( $t_existing_flags != $t_notify_flags )
 				|| ( $t_existing_access != $f_actions_access ) ) { # only set the flags if they are different
             config_set( 'notify_flags', $t_notify_flags, NO_USER, $t_project, $f_actions_access );
         }
@@ -164,4 +162,5 @@
 ?>
 </div>
 
-<?php html_page_bottom1( __FILE__ ) ?>
+<?php
+	html_page_bottom();
