@@ -1,34 +1,35 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: manage_custom_field_delete.php,v 1.17.2.1 2007-10-13 22:33:27 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
-	$t_core_path = config_get( 'core_path' );
+	require_once( 'custom_field_api.php' );
 
-	require_once( $t_core_path.'custom_field_api.php' );
+	form_security_validate('manage_custom_field_delete');
 
 	auth_reauthenticate();
-
 	access_ensure_global_level( config_get( 'manage_custom_fields_threshold' ) );
 
 	$f_field_id	= gpc_get_int( 'field_id' );
@@ -38,21 +39,19 @@
 
 	if( 0 < count( custom_field_get_project_ids( $f_field_id ) ) ) {
 		helper_ensure_confirmed( lang_get( 'confirm_used_custom_field_deletion' ) .
-			'<br/>' . lang_get( 'custom_field' ) . ': ' . string_attribute( $t_definition['name'] ),
+			'<br />' . lang_get( 'custom_field' ) . ': ' . string_attribute( $t_definition['name'] ),
 			lang_get( 'field_delete_button' ) );
 	} else {
 		helper_ensure_confirmed( lang_get( 'confirm_custom_field_deletion' ) .
-			'<br/>' . lang_get( 'custom_field' ) . ': ' . string_attribute( $t_definition['name'] ),
+			'<br />' . lang_get( 'custom_field' ) . ': ' . string_attribute( $t_definition['name'] ),
 			lang_get( 'field_delete_button' ) );
 	}
 
-	form_security_validate('manage_custom_field_delete');
-
 	custom_field_destroy( $f_field_id );
 
-	html_page_top1();
-	html_meta_redirect( $f_return );
-	html_page_top2();
+	form_security_purge('manage_custom_field_delete');
+
+	html_page_top( null, $f_return );
 ?>
 
 <br />
@@ -63,4 +62,5 @@
 ?>
 </div>
 
-<?php html_page_bottom1( __FILE__ ) ?>
+<?php
+	html_page_bottom();
