@@ -1,34 +1,35 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: manage_proj_cat_copy.php,v 1.22.2.1 2007-10-13 22:33:31 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
-	$t_core_path = config_get( 'core_path' );
+	require_once( 'category_api.php' );
 
-	require_once( $t_core_path.'category_api.php' );
+	form_security_validate( 'manage_proj_cat_copy' );
 
 	auth_reauthenticate();
-	form_security_validate( 'manage_proj_cat_copy' );
 
 	$f_project_id		= gpc_get_int( 'project_id' );
 	$f_other_project_id	= gpc_get_int( 'other_project_id' );
@@ -51,12 +52,19 @@
 	$rows = category_get_all_rows( $t_src_project_id );
 
 	foreach ( $rows as $row ) {
-		$t_category = $row['category'];
+		$t_name = $row['name'];
 
-		if ( category_is_unique( $t_dst_project_id, $t_category ) ) {
-			category_add( $t_dst_project_id, $t_category );
+		if ( category_is_unique( $t_dst_project_id, $t_name ) ) {
+			category_add( $t_dst_project_id, $t_name );
 		}
 	}
 
-	print_header_redirect( 'manage_proj_edit_page.php?project_id=' . $f_project_id );
-?>
+	form_security_purge( 'manage_proj_cat_copy' );
+
+	if ( $f_project_id == ALL_PROJECTS ) {
+		$t_redirect_url = 'manage_proj_page.php';
+	} else {
+		$t_redirect_url = 'manage_proj_edit_page.php?project_id=' . $f_project_id;
+	}
+
+	print_header_redirect( $t_redirect_url );
