@@ -1,32 +1,47 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# MantisBT - a php based bugtracking system
+
+# MantisBT is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# MantisBT is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
+
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
+	require_once( 'core.php' );
+
+	auth_reauthenticate();
 
-	# --------------------------------------------------------
-	# $Id: manage_proj_create_page.php,v 1.11 2005/08/10 14:20:15 thraxisp Exp $
-	# --------------------------------------------------------
-?>
-<?php require_once( 'core.php' ) ?>
-<?php
 	access_ensure_global_level( config_get( 'create_project_threshold' ) );
-?>
-<?php html_page_top1() ?>
-<?php html_page_top2() ?>
 
-<?php print_manage_menu( 'manage_proj_create_page.php' ) ?>
+	html_page_top();
+
+	print_manage_menu( 'manage_proj_create_page.php' );
 
-<?php
 	$f_parent_id = gpc_get( 'parent_id', null );
 ?>
 
 <br />
 <div align="center">
 <form method="post" action="manage_proj_create.php">
-<?php 
-	if ( null !== $f_parent_id ) { 
+<?php
+	echo form_security_field( 'manage_proj_create' );
+	if ( null !== $f_parent_id ) {
 		$f_parent_id = (int) $f_parent_id;
 ?>
 <input type="hidden" name="parent_id" value="<?php echo $f_parent_id ?>">
@@ -71,15 +86,39 @@
 		</select>
 	</td>
 </tr>
-<?php
+<tr class="row-2">
+	<td class="category">
+		<?php echo lang_get( 'inherit_global' ) ?>
+	</td>
+	<td>
+		<input type="checkbox" name="inherit_global" checked="checked" />
+	</td>
+</tr>
+<?php if ( !is_null( $f_parent_id ) ) { ?>
+<tr class="row-1">
+	<td class="category">
+		<?php echo lang_get( 'inherit_parent' ) ?>
+	</td>
+	<td>
+		<input type="checkbox" name="inherit_parent" checked="checked" />
+	</td>
+</tr>
+<?php 
+	} 
+
 	if ( config_get( 'allow_file_upload' ) ) {
+		$t_default_upload_path = '';
+		# Don't reveal the absolute path to non-administrators for security reasons
+		if ( current_user_is_administrator() ) {
+			$t_default_upload_path = config_get( 'absolute_path_default_upload_folder' );
+		}
 	?>
 		<tr class="row-2">
 			<td class="category">
 				<?php echo lang_get( 'upload_file_path' ) ?>
 			</td>
 			<td>
-				<input type="text" name="file_path" size="70" maxlength="250" />
+				<input type="text" name="file_path" size="70" maxlength="250" value="<?php echo $t_default_upload_path ?>" />
 			</td>
 		</tr>
 		<?php
@@ -90,9 +129,12 @@
 		<?php echo lang_get( 'description' ) ?>
 	</td>
 	<td>
-		<textarea name="description" cols="60" rows="5" wrap="virtual"></textarea>
+		<textarea name="description" cols="60" rows="5"></textarea>
 	</td>
 </tr>
+
+<?php event_signal( 'EVENT_MANAGE_PROJECT_CREATE_FORM' ) ?>
+
 <tr>
 	<td class="center" colspan="2">
 		<input type="submit" class="button" value="<?php echo lang_get( 'add_project_button' ) ?>" />
@@ -102,4 +144,5 @@
 </form>
 </div>
 
-<?php html_page_bottom1( __FILE__ ) ?>
+<?php
+	html_page_bottom();
