@@ -1,31 +1,34 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: manage_proj_user_copy.php,v 1.6.2.1 2007-10-13 22:33:44 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
-	auth_reauthenticate();
 	form_security_validate( 'manage_proj_user_copy' );
 
+	auth_reauthenticate();
+
 	$f_project_id		= gpc_get_int( 'project_id' );
 	$f_other_project_id	= gpc_get_int( 'other_project_id' );
 	$f_copy_from		= gpc_get_bool( 'copy_from' );
@@ -38,7 +41,7 @@
 		$t_src_project_id = $f_project_id;
 		$t_dst_project_id = $f_other_project_id;
 	} else {
-		# @@@ Should this become a separate error?
+		/** @todo Should this become a separate error? */
 		trigger_error( ERROR_CATEGORY_NO_ACTION, ERROR );
 	}
 
@@ -48,7 +51,8 @@
 	access_ensure_project_level( config_get( 'manage_project_threshold' ), $t_dst_project_id );
 	access_ensure_project_level( config_get( 'project_user_threshold' ), $t_dst_project_id );
 
-	project_copy_users( $t_dst_project_id, $t_src_project_id );
+	project_copy_users( $t_dst_project_id, $t_src_project_id, access_get_project_level( $t_dst_project_id ) );
+
+	form_security_purge( 'manage_proj_user_copy' );
 
 	print_header_redirect( 'manage_proj_edit_page.php?project_id=' . $f_project_id );
-?>
