@@ -1,28 +1,31 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: manage_proj_user_remove.php,v 1.9.2.1 2007-10-13 22:33:45 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
+	form_security_validate( 'manage_proj_user_remove' );
 	auth_reauthenticate();
 
 	$f_project_id = gpc_get_int( 'project_id' );
@@ -38,27 +41,27 @@
 		# Confirm with the user
 		helper_ensure_confirmed( lang_get( 'remove_all_users_sure_msg' ), lang_get( 'remove_all_users_button' ) );
 
-		form_security_validate( 'manage_proj_user_remove' );
+		project_remove_all_users( $f_project_id, access_get_project_level( $f_project_id ) );
+	} else {
+		# Don't allow removal of users from the project who have a higher access level than the current user
+		access_ensure_project_level( access_get_project_level( $f_project_id, $f_user_id ), $f_project_id );
 
-		project_remove_all_users( $f_project_id );
-	}
-	else {
 		$t_user = user_get_row( $f_user_id );
+		$t_project_name = project_get_name( $f_project_id );
+
 		# Confirm with the user
 		helper_ensure_confirmed( lang_get( 'remove_user_sure_msg' ) .
-			'<br/>' . lang_get( 'username' ) . ': ' . $t_user['username'],
-			lang_get( 'remove_user_button' ) );
-
-		form_security_validate( 'manage_proj_user_remove' );
+			'<br />' . lang_get( 'username' ) . ': ' . $t_user['username'],
+			sprintf( lang_get( 'remove_user_from_project_button' ), $t_project_name ) );
 
 		project_remove_user( $f_project_id, $f_user_id );
 	}
 
+	form_security_purge( 'manage_proj_user_remove' );
+
 	$t_redirect_url = 'manage_proj_edit_page.php?project_id=' . $f_project_id;
 
-	html_page_top1();
-	html_meta_redirect( $t_redirect_url );
-	html_page_top2();
+	html_page_top( null, $t_redirect_url );
 ?>
 <br />
 <div align="center">
@@ -68,4 +71,5 @@
 ?>
 </div>
 
-<?php html_page_bottom1( __FILE__ ) ?>
+<?php
+	html_page_bottom();
