@@ -1,31 +1,33 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: manage_proj_ver_delete.php,v 1.23.2.1 2007-10-13 22:33:47 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
-	$t_core_path = config_get( 'core_path' );
+	require_once( 'version_api.php' );
 
-	require_once( $t_core_path.'version_api.php' );
+	form_security_validate( 'manage_proj_ver_delete' );
 
 	auth_reauthenticate();
 
@@ -38,15 +40,14 @@
 
 	# Confirm with the user
 	helper_ensure_confirmed( lang_get( 'version_delete_sure' ) .
-		'<br/>' . lang_get( 'version' ) . ': ' . $t_version_info->version,
+		'<br />' . lang_get( 'version' ) . ': ' . $t_version_info->version,
 		lang_get( 'delete_version_button' ) );
 
-	form_security_validate( 'manage_proj_ver_delete' );
 	version_remove( $f_version_id );
 
-	html_page_top1();
-	html_meta_redirect( $t_redirect_url );
-	html_page_top2();
+	form_security_purge( 'manage_proj_ver_delete' );
+
+	html_page_top( null, $t_redirect_url );
 ?>
 <br />
 <div align="center">
@@ -56,4 +57,5 @@
 ?>
 </div>
 
-<?php html_page_bottom1( __FILE__ ) ?>
+<?php
+	html_page_bottom();
