@@ -1,33 +1,38 @@
 <?php
-# Mantis - a php based bugtracking system
+# MantisBT - a php based bugtracking system
 
-# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-# Copyright (C) 2002 - 2007  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-
-# Mantis is free software: you can redistribute it and/or modify
+# MantisBT is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 2 of the License, or
 # (at your option) any later version.
 #
-# Mantis is distributed in the hope that it will be useful,
+# MantisBT is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Mantis.  If not, see <http://www.gnu.org/licenses/>.
-
-	# --------------------------------------------------------
-	# $Id: signup_page.php,v 1.33.18.1 2007-10-13 22:34:31 giallu Exp $
-	# --------------------------------------------------------
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
 
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
 
 	# Check for invalid access to signup page
-	if ( OFF == config_get( 'allow_signup' ) ) {
+	if ( OFF == config_get_global( 'allow_signup' ) || LDAP == config_get_global( 'login_method' ) ) {
 		print_header_redirect( 'login_page.php' );
 	}
 
+	# signup page shouldn't be indexed by search engines
+	html_robots_noindex();
+
 	html_page_top1();
 	html_page_top2a();
 
@@ -49,7 +54,7 @@
 		<?php echo lang_get( 'username' ) ?>:
 	</td>
 	<td width="70%" colspan="2">
-		<input type="text" name="username" size="32" maxlength="32" />
+		<input type="text" name="username" size="32" maxlength="<?php echo DB_FIELD_SIZE_USERNAME;?>" />
 	</td>
 </tr>
 <tr class="row-2">
@@ -73,8 +78,8 @@
 		<?php print_captcha_input( 'captcha', '' ) ?>
 	</td>
 	<td>
-		<img src="make_captcha_img.php?public_key=<?php echo $t_key ?>">
-		<input type="hidden" name="public_key" value="<?php echo $t_key ?>">
+		<img src="make_captcha_img.php?public_key=<?php echo $t_key ?>" alt="visual captcha" />
+		<input type="hidden" name="public_key" value="<?php echo $t_key ?>" />
 	</td>
 </tr>
 <?php
@@ -93,9 +98,9 @@
 ?>
 <tr>
 	<td colspan="3">
-		<br/>
+		<br />
 		<?php echo lang_get( 'signup_info' ) ?>
-		<br/><br/>
+		<br /><br />
 	</td>
 </tr>
 <tr>
@@ -108,11 +113,11 @@
 </div>
 
 <?php
-	PRINT '<br /><div align="center">';
+	echo '<br /><div align="center">';
 	print_login_link();
-	PRINT '&nbsp;';
+	echo '&#160;';
 	print_lost_password_link();
-	PRINT '</div>';
+	echo '</div>';
 
 	if ( ON == config_get( 'use_javascript' ) ) {
 ?>
@@ -123,9 +128,8 @@
 	window.document.signup_form.username.focus();
 // -->
 </script>
-<?php } ?>
 <?php
 	}
+}
 
-	html_page_bottom1a( __FILE__ );
-?>
+html_page_bottom1a( __FILE__ );
