@@ -1,48 +1,58 @@
 <?php
-	# Mantis - a php based bugtracking system
-	# Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
-	# Copyright (C) 2002 - 2004  Mantis Team   - mantisbt-dev@lists.sourceforge.net
-	# This program is distributed under the terms and conditions of the GPL
-	# See the README and LICENSE files for details
+# MantisBT - a php based bugtracking system
 
-	# --------------------------------------------------------
-	# $Id: summary_page.php,v 1.42 2004/10/20 01:11:02 narcissus Exp $
-	# --------------------------------------------------------
-?>
-<?php
+# MantisBT is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# MantisBT is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with MantisBT.  If not, see <http://www.gnu.org/licenses/>.
+
+	/**
+	 * @package MantisBT
+	 * @copyright Copyright (C) 2000 - 2002  Kenzaburo Ito - kenito@300baud.org
+	 * @copyright Copyright (C) 2002 - 2011  MantisBT Team - mantisbt-dev@lists.sourceforge.net
+	 * @link http://www.mantisbt.org
+	 */
+	 /**
+	  * MantisBT Core API's
+	  */
 	require_once( 'core.php' );
-	
-	$t_core_path = config_get( 'core_path' );
-	
-	require_once( $t_core_path.'summary_api.php' );
-?>
-<?php
+
+	require_once( 'summary_api.php' );
+
+	$f_project_id = gpc_get_int( 'project_id', helper_get_current_project() );
+
+	# Override the current page to make sure we get the appropriate project-specific configuration
+	$g_project_override = $f_project_id;
+
 	access_ensure_project_level( config_get( 'view_summary_threshold' ) );
 
-	$t_project_id = helper_get_current_project();
 	$t_user_id = auth_get_current_user_id();
 
-	#checking if it's a per project statistic or all projects
-	if ( ALL_PROJECTS == $t_project_id ) {
-		# Only projects to which the user have access
-		$t_accessible_projects_array = user_get_accessible_projects( $t_user_id );
-		if ( count( $t_accessible_projects_array ) > 0 ) {
-			$specific_where = ' (project_id='. implode( ' OR project_id=', $t_accessible_projects_array ).')';
-		} else {
-			$specific_where = '1=1';
-		}
-	} else {
-		$specific_where = " project_id='$t_project_id'";
-	}
+	$t_project_ids = user_get_all_accessible_projects( $t_user_id, $f_project_id);
+	$specific_where = helper_project_specific_where( $f_project_id, $t_user_id);
 
-	$t_bug_table = config_get( 'mantis_bug_table' );
-	$t_history_table = config_get( 'mantis_bug_history_table' );
+	$t_bug_table = db_get_table( 'mantis_bug_table' );
+	$t_history_table = db_get_table( 'mantis_bug_history_table' );
 
-	$t_clo_val = config_get( 'bug_resolved_status_threshold' );
-	$query = "SELECT id, date_submitted, last_updated, status
-			FROM $t_bug_table
-			WHERE $specific_where AND status>='$t_clo_val'";
-	$result = db_query( $query );
+	$t_resolved = config_get( 'bug_resolved_status_threshold' );
+	# the issue may have passed through the status we consider resolved
+	#  (e.g., bug is CLOSED, not RESOLVED). The linkage to the history field
+	#  will look up the most recent 'resolved' status change and return it as well
+	$query = "SELECT b.id, b.date_submitted, b.last_updated, MAX(h.date_modified) as hist_update, b.status
+        FROM $t_bug_table b LEFT JOIN $t_history_table h
+            ON b.id = h.bug_id  AND h.type=0 AND h.field_name='status' AND h.new_value=" . db_param() . "
+            WHERE b.status >=" . db_param() . " AND $specific_where
+            GROUP BY b.id, b.status, b.date_submitted, b.last_updated
+            ORDER BY b.id ASC";
+	$result = db_query_bound( $query, Array( $t_resolved, $t_resolved ) );
 	$bug_count = db_num_rows( $result );
 
 	$t_bug_id       = 0;
@@ -50,27 +60,14 @@
 	$t_total_time   = 0;
 	for ($i=0;$i<$bug_count;$i++) {
 		$row = db_fetch_array( $result );
-		$t_date_submitted = db_unixtimestamp( $row['date_submitted'] );
-		$t_last_updated   = db_unixtimestamp( $row['last_updated'] );
+		$t_date_submitted = $row['date_submitted'];
 		$t_id = $row['id'];
 		$t_status = $row['status'];
-
-		# if the status is not the closed value, it may have passed through the
-		#  status we consider closed (e.g., bug is CLOSED, not RESOLVED)
-		#  we should look for the last time it was RESOLVED in the history
-		if ( $t_status <> $t_clo_val ) {
-			$query2 = "SELECT date_modified
-				FROM " . $t_history_table . "
-				WHERE bug_id=$t_id AND type=" . NORMAL_TYPE . 
-							" AND field_name='status' AND new_value='$t_clo_val'
-				ORDER BY date_modified DESC";
-			$result2 = db_query( $query2 );
-			if ( db_num_rows( $result2 ) >= 1 ) {
-				# if any were found, read the first (oldest) one and update the timestamp
-				$row2 = db_fetch_array( $result2 );
-				$t_last_updated   = db_unixtimestamp( $row2['date_modified'] );
-			}
-		}		
+		if ( $row['hist_update'] !== NULL ) {
+            $t_last_updated   = $row['hist_update'];
+        } else {
+        	$t_last_updated   = $row['last_updated'];
+        }
 
 		if ($t_last_updated < $t_date_submitted) {
 			$t_last_updated   = 0;
@@ -89,26 +86,26 @@
 	}
 	$t_average_time 	= $t_total_time / $bug_count;
 
-	$t_largest_diff 	= number_format( $t_largest_diff / 86400, 2 );
-	$t_total_time		= number_format( $t_total_time / 86400, 2 );
-	$t_average_time 	= number_format( $t_average_time / 86400, 2 );
-	
+	$t_largest_diff 	= number_format( $t_largest_diff / SECONDS_PER_DAY, 2 );
+	$t_total_time		= number_format( $t_total_time / SECONDS_PER_DAY, 2 );
+	$t_average_time 	= number_format( $t_average_time / SECONDS_PER_DAY, 2 );
+
 	$t_orct_arr = preg_split( '/[\)\/\(]/', lang_get( 'orct' ), -1, PREG_SPLIT_NO_EMPTY );
 
 	$t_orcttab = "";
 	foreach ( $t_orct_arr as $t_orct_s ) {
 		$t_orcttab .= '<td class="right">';
-		$t_orcttab .= ucwords( $t_orct_s );
+		$t_orcttab .= $t_orct_s;
 		$t_orcttab .= '</td>';
 	}
+
+	html_page_top( lang_get( 'summary_link' ) );
 ?>
-<?php html_page_top1( lang_get( 'summary_link' ) ) ?>
-<?php html_page_top2() ?>
 
 <br />
-<?php print_summary_menu( 'summary_page.php' ) ?>
-
-<?php print_menu_graph() ?>
+<?php 
+	print_summary_menu( 'summary_page.php' );
+	print_summary_submenu(); ?>
 <br />
 <table class="width100" cellspacing="1">
 <tr>
@@ -118,8 +115,8 @@
 </tr>
 <tr valign="top">
 	<td width="50%">
-		<?php # PROJECT # ?>
-		<?php if ( ALL_PROJECTS == $t_project_id ) { ?>
+		<?php # PROJECT # 
+			if ( 1 < count( $t_project_ids ) ) { ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -133,7 +130,6 @@
 		<br />
 		<?php } ?>
 
-		<?php # STATUS # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -141,12 +137,11 @@
 			</td>
 			<?php echo $t_orcttab ?>
 		</tr>
-		<?php summary_print_by_enum( config_get( 'status_enum_string' ), 'status' ) ?>
+		<?php summary_print_by_enum( 'status' ) ?>
 		</table>
 
 		<br />
 
-		<?php # SEVERITY # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -154,12 +149,11 @@
 			</td>
 			<?php echo $t_orcttab ?>
 		</tr>
-		<?php summary_print_by_enum( config_get( 'severity_enum_string' ), 'severity' ) ?>
+		<?php summary_print_by_enum( 'severity' ) ?>
 		</table>
 
 		<br />
 
-		<?php # CATEGORY # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -172,7 +166,6 @@
 
 		<br />
 
-		<?php # MISCELLANEOUS # ?>
 		<table class="width100">
 		<tr>
 			<td class="form-title" colspan="5">
@@ -219,7 +212,6 @@
 
 		<br />
 
-		<?php # DEVELOPER # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -234,19 +226,38 @@
 
 
 	<td width="50%">
-		<?php # DATE # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
-			<td class="form-title" colspan="5">
-				<?php echo lang_get( 'by_date' ) ?>
-			</td>
+			<td class="form-title"><?php echo lang_get( 'by_date' ); ?></td>
+			<td class="right"><?php echo lang_get( 'opened' ); ?></td>
+			<td class="right"><?php echo lang_get( 'resolved' ); ?></td>
+			<td class="right"><?php echo lang_get( 'balance' ); ?></td>
 		</tr>
 		<?php summary_print_by_date( config_get( 'date_partitions' ) ) ?>
 		</table>
 
 		<br />
 
-		<?php # RESOLUTION # ?>
+		<table class="width100" cellspacing="1">
+		<tr>
+			<td class="form-title" width="86%"><?php echo lang_get( 'most_active' ); ?></td>
+			<td class="right" width="14%"><?php echo lang_get( 'score' ); ?></td>
+		</tr>
+		<?php summary_print_by_activity() ?>
+		</table>
+
+		<br />
+
+		<table class="width100" cellspacing="1">
+		<tr>
+			<td class="form-title" width="86%"><?php echo lang_get( 'longest_open' ); ?></td>
+			<td class="right" width="14%"><?php echo lang_get( 'days' ); ?></td>
+		</tr>
+		<?php summary_print_by_age() ?>
+		</table>
+
+		<br />
+
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -254,12 +265,11 @@
 			</td>
 			<?php echo $t_orcttab ?>
 		</tr>
-		<?php summary_print_by_enum( config_get( 'resolution_enum_string' ), 'resolution' ) ?>
+		<?php summary_print_by_enum( 'resolution' ) ?>
 		</table>
 
 		<br />
 
-		<?php # PRIORITY # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -267,12 +277,11 @@
 			</td>
 			<?php echo $t_orcttab ?>
 		</tr>
-		<?php summary_print_by_enum( config_get( 'priority_enum_string' ), 'priority' ) ?>
+		<?php summary_print_by_enum( 'priority' ) ?>
 		</table>
 
 		<br />
 
-		<?php # REPORTER # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -285,7 +294,6 @@
 
 		<br />
 
-		<?php # REPORTER EFFECTIVENESS # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
@@ -308,27 +316,19 @@
 
 <tr valign="top">
 	<td colspan="2">
-		<?php # REPORTER / RESOLUTION # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
 				<?php echo lang_get( 'reporter_by_resolution' ) ?>
 			</td>
 			<?php
-			$t_arr = explode_enum_string( config_get( 'resolution_enum_string' ) );
-			$enum_count = count( $t_arr );
+			$t_resolutions = MantisEnum::getValues( config_get( 'resolution_enum_string' ) );
 
-			for ($i=0;$i<$enum_count;$i++) {
-				print '<td>';
-				$t_s = explode_enum_arr( $t_arr[$i] );
-				$c_s[0] = db_prepare_string( $t_s[0] );
-				echo ucwords( get_enum_element( 'resolution', $c_s[0] ) );
-				print '</td>';
+			foreach ( $t_resolutions as $t_resolution ) {
+				echo '<td>', get_enum_element( 'resolution', $t_resolution ), '</td>';
 			}
-			
-			print '<td>';
-			print lang_get( 'percentage_errors' );
-			print '</td>';
+
+			echo '<td>', lang_get( 'percentage_errors' ), '</td>';
 			?>
 		</tr>
 		<?php summary_print_reporter_resolution( config_get( 'resolution_enum_string' ) ) ?>
@@ -338,27 +338,19 @@
 
 <tr valign="top">
 	<td colspan="2">
-		<?php # DEVELOPER / RESOLUTION # ?>
 		<table class="width100" cellspacing="1">
 		<tr>
 			<td class="form-title" colspan="1">
 				<?php echo lang_get( 'developer_by_resolution' ) ?>
 			</td>
 			<?php
-			$t_arr = explode_enum_string( config_get( 'resolution_enum_string' ) );
-			$enum_count = count( $t_arr );
+			$t_resolutions = MantisEnum::getValues( config_get( 'resolution_enum_string' ) );
 
-			for ($i=0;$i<$enum_count;$i++) {
-				print '<td>';
-				$t_s = explode_enum_arr( $t_arr[$i] );
-				$c_s[0] = db_prepare_string( $t_s[0] );
-				echo ucwords( get_enum_element( 'resolution', $c_s[0] ) );
-				print '</td>';
+			foreach ( $t_resolutions as $t_resolution ) {
+				echo '<td>', get_enum_element( 'resolution', $t_resolution ), '</td>';
 			}
-			
-			print '<td>';
-			print lang_get( 'percentage_fixed' );
-			print '</td>';
+
+			echo '<td>', lang_get( 'percentage_fixed' ), '</td>';
 			?>
 		</tr>
 		<?php summary_print_developer_resolution( config_get( 'resolution_enum_string' ) ) ?>
@@ -367,4 +359,5 @@
 </tr>
 </table>
 
-<?php html_page_bottom1( __FILE__ ) ?>
+<?php
+	html_page_bottom();
